@@ -5,12 +5,14 @@ namespace Icinga\Controllers;
 
 use Exception;
 use Icinga\Application\Logger;
+use Icinga\Authentication\User\DomainAwareInterface;
 use Icinga\Data\DataArray\ArrayDatasource;
 use Icinga\Data\Filter\Filter;
 use Icinga\Data\Reducible;
 use Icinga\Exception\NotFoundError;
 use Icinga\Forms\Config\UserGroup\AddMemberForm;
 use Icinga\Forms\Config\UserGroup\UserGroupForm;
+use Icinga\User;
 use Icinga\Web\Controller\AuthBackendController;
 use Icinga\Web\Form;
 use Icinga\Web\Notification;
@@ -19,6 +21,13 @@ use Icinga\Web\Widget;
 
 class GroupController extends AuthBackendController
 {
+    public function init()
+    {
+        $this->view->title = $this->translate('User Groups');
+
+        parent::init();
+    }
+
     /**
      * List all user groups of a single backend
      */
@@ -27,7 +36,9 @@ class GroupController extends AuthBackendController
         $this->assertPermission('config/authentication/groups/show');
         $this->createListTabs()->activate('group/list');
         $backendNames = array_map(
-            function ($b) { return $b->getName(); },
+            function ($b) {
+                return $b->getName();
+            },
             $this->loadUserGroupBackends('Icinga\Data\Selectable')
         );
         if (empty($backendNames)) {
@@ -35,7 +46,7 @@ class GroupController extends AuthBackendController
         }
 
         $this->view->backendSelection = new Form();
-        $this->view->backendSelection->setAttrib('class', 'backend-selection');
+        $this->view->backendSelection->setAttrib('class', 'backend-selection icinga-controls');
         $this->view->backendSelection->setUidDisabled();
         $this->view->backendSelection->setMethod('GET');
         $this->view->backendSelection->setTokenDisabled();
@@ -117,6 +128,7 @@ class GroupController extends AuthBackendController
         if ($this->hasPermission('config/authentication/groups/edit') && $backend instanceof Reducible) {
             $removeForm = new Form();
             $removeForm->setUidDisabled();
+            $removeForm->setAttrib('class', 'inline');
             $removeForm->setAction(
                 Url::fromPath('group/removemember', array('backend' => $backend->getName(), 'group' => $groupName))
             );
@@ -295,8 +307,27 @@ class GroupController extends AuthBackendController
         $users = array();
         foreach ($this->loadUserBackends('Icinga\Data\Selectable') as $backend) {
             try {
-                foreach ($backend->select(array('user_name')) as $row) {
-                    $users[] = $row;
+                if ($backend instanceof DomainAwareInterface) {
+                    $domain = $backend->getDomain();
+                } else {
+                    $domain = null;
+                }
+                foreach ($backend->select(array('user_name')) as $user) {
+                    $userObj = new User($user->user_name);
+                    if ($domain !== null) {
+                        if ($userObj->hasDomain() && $userObj->getDomain() !== $domain) {
+                            // Users listed in a user backend which is configured to be responsible for a domain should
+                            // not have a domain in their username. Ultimately, if the username has a domain, it must
+                            // not differ from the backend's domain. We could log here - but hey, who cares :)
+                            continue;
+                        } else {
+                            $userObj->setDomain($domain);
+                        }
+                    }
+
+                    $user->user_name = $userObj->getUsername();
+
+                    $users[] = $user;
                 }
             } catch (Exception $e) {
                 Logger::error($e);
