@@ -268,6 +268,7 @@ class Donut
         $svg['content'][] = array(
             'tag'        => 'circle',
             'attributes' => array(
+                'aria-hidden' => true,
                 'cx'           => 20,
                 'cy'           => 20,
                 'r'            => sprintf('%F', $this->radius),
@@ -297,7 +298,9 @@ class Donut
                     'r'                 => sprintf('%F', $this->radius),
                     'fill'              => 'transparent',
                     'stroke-width'      => $this->getThickness(),
-                    'stroke-dasharray'  => sprintf('%F', $slice[0]) . ' ' . sprintf('%F', (99.9 - $slice[0])), // 99.9 prevents gaps (slight overlap)
+                    'stroke-dasharray'  => sprintf('%F', $slice[0])
+                        . ' '
+                        . sprintf('%F', (99.9 - $slice[0])), // 99.9 prevents gaps (slight overlap)
                     'stroke-dashoffset' => sprintf('%F', $offset)
                 )
             );
@@ -327,6 +330,7 @@ class Donut
                     array(
                         'tag' => 'a',
                         'attributes' => array(
+                            'aria-label' => $labelBig . ' ' . $labelSmall,
                             'href' => $this->getLabelBigUrl() ? $this->getLabelBigUrl()->getAbsoluteUrl() : null,
                             'class' => $this->labelBigEyeCatching
                                 ? 'donut-label-big donut-label-big-eye-catching'
