@@ -187,6 +187,11 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                     if ($this->config->ssl_cipher) {
                         $adapterParamaters['driver_options'][PDO::MYSQL_ATTR_SSL_CIPHER] = $this->config->ssl_cipher;
                     }
+                    if (defined('PDO::MYSQL_ATTR_SSL_VERIFY_SERVER_CERT')
+                        && $this->config->ssl_do_not_verify_server_cert
+                    ) {
+                        $adapterParamaters['driver_options'][PDO::MYSQL_ATTR_SSL_VERIFY_SERVER_CERT] = false;
+                    }
                 }
                 /*
                  * Set MySQL server SQL modes to behave as closely as possible to Oracle and PostgreSQL. Note that the
@@ -200,8 +205,15 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                     . 'ANSI_QUOTES,PIPES_AS_CONCAT,NO_ENGINE_SUBSTITUTION\'';
                 if (isset($adapterParamaters['charset'])) {
                     $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .= ', NAMES ' . $adapterParamaters['charset'];
+                    if (trim($adapterParamaters['charset']) === 'latin1') {
+                        // Required for MySQL 8+ because we need PIPES_AS_CONCAT and
+                        // have several columns with explicit COLLATE instructions
+                        $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .= ' COLLATE latin1_general_ci';
+                    }
+
                     unset($adapterParamaters['charset']);
                 }
+
                 $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .= ", time_zone='" . $this->defaultTimezoneOffset() . "'";
                 $driverOptions[PDO::MYSQL_ATTR_INIT_COMMAND] .=';';
                 $defaultPort = 3306;
@@ -218,6 +230,11 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
             case 'oracle':
                 $adapter = 'Pdo_Oci';
                 $defaultPort = 1521;
+
+                // remove host parameter when not configured
+                if (empty($this->config->host)) {
+                    unset($adapterParamaters['host']);
+                }
                 break;
             case 'pgsql':
                 $adapter = 'Pdo_Pgsql';
@@ -574,7 +591,7 @@ class DbConnection implements Selectable, Extensible, Updatable, Reducible, Insp
                 'Connection to %s as %s on %s:%s successful',
                 $config['dbname'],
                 $config['username'],
-                $config['host'],
+                array_key_exists('host', $config) ? $config['host'] : '(none)',
                 $config['port']
             ));
             switch ($this->dbType) {
