@@ -5,6 +5,7 @@ namespace Icinga\Protocol\Ldap;
 
 use ArrayIterator;
 use Exception;
+use Icinga\Data\Filter\FilterNot;
 use LogicException;
 use stdClass;
 use Icinga\Application\Config;
@@ -76,6 +77,9 @@ class LdapConnection implements Selectable, Inspectable
      */
     const LDAPS = 'ldaps';
 
+    /** @var ConfigObject Connection configuration */
+    protected $config;
+
     /**
      * Encryption for the connection if any
      *
@@ -181,6 +185,7 @@ class LdapConnection implements Selectable, Inspectable
      */
     public function __construct(ConfigObject $config)
     {
+        $this->config = $config;
         $this->hostname = $config->hostname;
         $this->bindDn = $config->bind_dn;
         $this->bindPw = $config->bind_pw;
@@ -738,7 +743,8 @@ class LdapConnection implements Selectable, Inspectable
 
         $ds = $this->getConnection();
 
-        $serverSorting = $this->getCapabilities()->hasOid(LdapCapabilities::LDAP_SERVER_SORT_OID);
+        $serverSorting = ! $this->config->disable_server_side_sort
+            && $this->getCapabilities()->hasOid(LdapCapabilities::LDAP_SERVER_SORT_OID);
 
         if ($query->hasOrder()) {
             if ($serverSorting) {
@@ -888,13 +894,17 @@ class LdapConnection implements Selectable, Inspectable
             }
         }
 
+        $legacyControlHandling = version_compare(PHP_VERSION, '7.3.0') < 0;
+
         $count = 0;
         $cookie = '';
         $entries = array();
         do {
-            // Do not request the pagination control as a critical extension, as we want the
-            // server to return results even if the paged search request cannot be satisfied
-            ldap_control_paged_result($ds, $pageSize, false, $cookie);
+            if ($legacyControlHandling) {
+                // Do not request the pagination control as a critical extension, as we want the
+                // server to return results even if the paged search request cannot be satisfied
+                ldap_control_paged_result($ds, $pageSize, false, $cookie);
+            }
 
             if ($serverSorting && $query->hasOrder()) {
                 ldap_set_option($ds, LDAP_OPT_SERVER_CONTROLS, array(
@@ -909,7 +919,10 @@ class LdapConnection implements Selectable, Inspectable
                 $query,
                 array_values($fields),
                 0,
-                ($serverSorting || ! $query->hasOrder()) && $limit ? $offset + $limit : 0
+                ($serverSorting || ! $query->hasOrder()) && $limit ? $offset + $limit : 0,
+                0,
+                LDAP_DEREF_NEVER,
+                $legacyControlHandling ? null : $pageSize
             );
             if ($results === false) {
                 if (ldap_errno($ds) === self::LDAP_NO_SUCH_OBJECT) {
@@ -975,7 +988,7 @@ class LdapConnection implements Selectable, Inspectable
                 && ($entry = ldap_next_entry($ds, $entry))
             );
 
-            if (false === @ldap_control_paged_result_response($ds, $results, $cookie)) {
+            if ($legacyControlHandling && false === @ldap_control_paged_result_response($ds, $results, $cookie)) {
                 // If the page size is greater than or equal to the sizeLimit value, the server should ignore the
                 // control as the request can be satisfied in a single page: https://www.ietf.org/rfc/rfc2696.txt
                 // This applies no matter whether paged search requests are permitted or not. You're done once you
@@ -992,7 +1005,7 @@ class LdapConnection implements Selectable, Inspectable
             ldap_free_result($results);
         } while ($cookie && (! $serverSorting || $limit === 0 || count($entries) < $limit));
 
-        if ($cookie) {
+        if ($legacyControlHandling && $cookie) {
             // A sequence of paged search requests is abandoned by the client sending a search request containing a
             // pagedResultsControl with the size set to zero (0) and the cookie set to the last cookie returned by
             // the server: https://www.ietf.org/rfc/rfc2696.txt
@@ -1218,6 +1231,7 @@ class LdapConnection implements Selectable, Inspectable
      * @param   int         $sizelimit      Enables you to limit the count of entries fetched
      * @param   int         $timelimit      Sets the number of seconds how long is spend on the search
      * @param   int         $deref
+     * @param   int         $pageSize       The page size to request (Only supported with PHP v7.3+)
      *
      * @return  resource|bool               A search result identifier or false on error
      *
@@ -1229,7 +1243,8 @@ class LdapConnection implements Selectable, Inspectable
         $attrsonly = 0,
         $sizelimit = 0,
         $timelimit = 0,
-        $deref = LDAP_DEREF_NEVER
+        $deref = LDAP_DEREF_NEVER,
+        $pageSize = null
     ) {
         $queryString = (string) $query;
         $baseDn = $query->getBase() ?: $this->getDn();
@@ -1254,7 +1269,7 @@ class LdapConnection implements Selectable, Inspectable
                 $derefName = 'find';
             }
 
-            Logger::debug("Issueing LDAP search. Use '%s' to reproduce.", sprintf(
+            Logger::debug("Issuing LDAP search. Use '%s' to reproduce.", sprintf(
                 'ldapsearch -P 3%s -H "%s"%s -b "%s" -s "%s" -z %u -l %u -a "%s"%s%s%s',
                 $starttlsParam,
                 $this->normalizeHostname($this->hostname),
@@ -1284,16 +1299,41 @@ class LdapConnection implements Selectable, Inspectable
                 throw new LogicException('LDAP scope %s not supported by ldapSearch', $scope);
         }
 
-        return @$function(
-            $this->getConnection(),
-            $baseDn,
-            $queryString,
-            $attributes,
-            $attrsonly,
-            $sizelimit,
-            $timelimit,
-            $deref
-        );
+        if ($pageSize !== null) {
+            $serverctrls[] = [
+                'oid' => LDAP_CONTROL_PAGEDRESULTS,
+                // Do not request the pagination control as a critical extension, as we want the
+                // server to return results even if the paged search request cannot be satisfied
+                'iscritical' => false,
+                'value' => [
+                    'size' => $pageSize,
+                    'cookie' => ''
+                ]
+            ];
+
+            return @$function(
+                $this->getConnection(),
+                $baseDn,
+                $queryString,
+                $attributes,
+                $attrsonly,
+                $sizelimit,
+                $timelimit,
+                $deref,
+                $serverctrls
+            );
+        } else {
+            return @$function(
+                $this->getConnection(),
+                $baseDn,
+                $queryString,
+                $attributes,
+                $attrsonly,
+                $sizelimit,
+                $timelimit,
+                $deref
+            );
+        }
     }
 
     /**
@@ -1390,7 +1430,7 @@ class LdapConnection implements Selectable, Inspectable
         }
 
         $format = '%1$s(%2$s)';
-        if (count($parts) === 1) {
+        if (count($parts) === 1 && ! $filter instanceof FilterNot) {
             $format = '%2$s';
         }
         if ($level === 0) {
@@ -1498,7 +1538,10 @@ class LdapConnection implements Selectable, Inspectable
         try {
             $cap = LdapCapabilities::discoverCapabilities($this);
             $discovery = new Inspection('Discovery Results');
-            $discovery->write($cap->getVendor());
+            $vendor = $cap->getVendor();
+            if (isset($vendor)) {
+                $discovery->write($vendor);
+            }
             $version = $cap->getVersion();
             if (isset($version)) {
                 $discovery->write($version);
