@@ -17,7 +17,6 @@ use Icinga\File\Pdf;
 use Icinga\Forms\AutoRefreshForm;
 use Icinga\Security\SecurityException;
 use Icinga\Util\Translator;
-use Icinga\Web\Notification;
 use Icinga\Web\Session;
 use Icinga\Web\Url;
 use Icinga\Web\UrlParams;
@@ -41,6 +40,16 @@ use Icinga\Web\Window;
  */
 class ActionController extends Zend_Controller_Action
 {
+    /**
+     * The login route to use when requiring authentication
+     */
+    const LOGIN_ROUTE = 'authentication/login';
+
+    /**
+     * The default page title to use
+     */
+    const DEFAULT_TITLE = 'Icinga Web';
+
     /**
      * Whether the controller requires the user to be authenticated
      *
@@ -53,17 +62,22 @@ class ActionController extends Zend_Controller_Action
      *
      * @var string
      */
-    private $moduleName;
+    protected $moduleName;
 
-    private $autorefreshInterval;
+    protected $autorefreshInterval;
 
-    private $reloadCss = false;
+    protected $reloadCss = false;
 
-    private $window;
+    protected $window;
 
-    private $rerenderLayout = false;
+    protected $rerenderLayout = false;
 
-    private $xhrLayout = 'inline';
+    /**
+     * The inline layout (inside columns) to use
+     *
+     * @var string
+     */
+    protected $inlineLayout = 'inline';
 
     /**
      * The inner layout (inside the body) to use
@@ -77,7 +91,7 @@ class ActionController extends Zend_Controller_Action
      *
      * @var Auth|null
      */
-    private $auth;
+    protected $auth;
 
     /**
      * URL parameters
@@ -108,20 +122,22 @@ class ActionController extends Zend_Controller_Action
             ->_setInvokeArgs($invokeArgs);
         $this->_helper = new Zend_Controller_Action_HelperBroker($this);
 
-        $this->handlerBrowserWindows();
         $moduleName = $this->getModuleName();
+        $this->view->defaultTitle = static::DEFAULT_TITLE;
         $this->view->translationDomain = $moduleName !== 'default' ? $moduleName : 'icinga';
         $this->_helper->layout()->isIframe = $request->getUrl()->shift('isIframe');
         $this->_helper->layout()->showFullscreen = $request->getUrl()->shift('showFullscreen');
         $this->_helper->layout()->moduleName = $moduleName;
 
-        $this->view->compact = $request->getParam('view') === 'compact';
+        $this->view->compact = false;
+        if ($request->getUrl()->getParam('view') === 'compact') {
+            $request->getUrl()->remove('view');
+            $this->view->compact = true;
+        }
         if ($request->getUrl()->shift('showCompact')) {
             $this->view->compact = true;
         }
-        if ($this->rerenderLayout = $request->getUrl()->shift('renderLayout')) {
-            $this->xhrLayout = $this->innerLayout;
-        }
+        $this->rerenderLayout = $request->getUrl()->shift('renderLayout');
         if ($request->getUrl()->shift('_disableLayout')) {
             $this->_helper->layout()->disableLayout();
         }
@@ -216,25 +232,12 @@ class ActionController extends Zend_Controller_Action
     public function Window()
     {
         if ($this->window === null) {
-            $this->window = new Window(
-                $this->_request->getHeader('X-Icinga-WindowId', Window::UNDEFINED)
-            );
+            $this->window = Window::getInstance();
         }
+
         return $this->window;
     }
 
-    protected function handlerBrowserWindows()
-    {
-        if ($this->isXhr()) {
-            $id = $this->_request->getHeader('X-Icinga-WindowId', null);
-
-            if ($id === Window::UNDEFINED) {
-                $this->window = new Window($id);
-                $this->_response->setHeader('X-Icinga-WindowId', Window::generateId());
-            }
-        }
-    }
-
     protected function reloadCss()
     {
         $this->reloadCss = true;
@@ -322,7 +325,13 @@ class ActionController extends Zend_Controller_Action
      */
     public function translatePlural($textSingular, $textPlural, $number, $context = null)
     {
-        return Translator::translatePlural($textSingular, $textPlural, $number, $this->view->translationDomain, $context);
+        return Translator::translatePlural(
+            $textSingular,
+            $textPlural,
+            $number,
+            $this->view->translationDomain,
+            $context
+        );
     }
 
     protected function ignoreXhrBody()
@@ -364,7 +373,7 @@ class ActionController extends Zend_Controller_Action
      */
     protected function redirectToLogin($redirect = null)
     {
-        $login = Url::fromPath('authentication/login');
+        $login = Url::fromPath(static::LOGIN_ROUTE);
         if ($this->isXhr()) {
             if ($redirect !== null) {
                 $login->setParam('redirect', '__SELF__');
@@ -387,7 +396,6 @@ class ActionController extends Zend_Controller_Action
     protected function rerenderLayout()
     {
         $this->rerenderLayout = true;
-        $this->xhrLayout = 'layout';
         return $this;
     }
 
@@ -398,33 +406,19 @@ class ActionController extends Zend_Controller_Action
 
     protected function redirectXhr($url)
     {
-        if (! $url instanceof Url) {
-            $url = Url::fromPath($url);
-        }
-
-        if ($this->rerenderLayout) {
-            $this->getResponse()->setHeader('X-Icinga-Rerender-Layout', 'yes');
-        }
-        if ($this->reloadCss) {
-            $this->getResponse()->setHeader('X-Icinga-Reload-Css', 'now');
-        }
-
-        $this->shutdownSession();
-
         $this->getResponse()
-            ->setHeader('X-Icinga-Redirect', rawurlencode($url->getAbsoluteUrl()))
-            ->sendHeaders();
-
-        exit;
+            ->setReloadCss($this->reloadCss)
+            ->setRerenderLayout($this->rerenderLayout)
+            ->redirectAndExit($url);
     }
 
     protected function redirectHttp($url)
     {
-        if (! $url instanceof Url) {
-            $url = Url::fromPath($url);
+        if ($this->isXhr()) {
+            $this->getResponse()->setHeader('X-Icinga-Redirect-Http', 'yes');
         }
-        $this->shutdownSession();
-        $this->_helper->Redirector->gotoUrlAndExit($url->getRelativeUrl());
+
+        $this->getResponse()->redirectAndExit($url);
     }
 
     /**
@@ -447,7 +441,9 @@ class ActionController extends Zend_Controller_Action
     public function preDispatch()
     {
         $form = new AutoRefreshForm();
-        $form->handleRequest();
+        if (! $this->getRequest()->isApiRequest()) {
+            $form->handleRequest();
+        }
         $this->_helper->layout()->autoRefreshForm = $form;
     }
 
@@ -463,6 +459,7 @@ class ActionController extends Zend_Controller_Action
         $req = $this->getRequest();
         $layout = $this->_helper->layout();
         $layout->innerLayout = $this->innerLayout;
+        $layout->inlineLayout = $this->inlineLayout;
 
         if ($user = $req->getUser()) {
             if ((bool) $user->getPreferences()->getValue('icingaweb', 'show_benchmark', false)) {
@@ -476,9 +473,9 @@ class ActionController extends Zend_Controller_Action
             }
         }
 
-        if ($req->getParam('format') === 'pdf') {
-            $this->shutdownSession();
+        if ($req->getParam('error_handler') === null && $req->getParam('format') === 'pdf') {
             $this->sendAsPdf();
+            $this->shutdownSession();
             exit;
         }
 
@@ -491,21 +488,10 @@ class ActionController extends Zend_Controller_Action
 
     protected function postDispatchXhr()
     {
-        $layout = $this->_helper->layout();
-        $layout->setLayout($this->xhrLayout);
         $resp = $this->getResponse();
 
-        $notifications = Notification::getInstance();
-        if ($notifications->hasMessages()) {
-            $notificationList = array();
-            foreach ($notifications->popMessages() as $m) {
-                $notificationList[] = rawurlencode($m->type . ' ' . $m->message);
-            }
-            $resp->setHeader('X-Icinga-Notification', implode('&', $notificationList), true);
-        }
-
         if ($this->reloadCss) {
-            $resp->setHeader('X-Icinga-CssReload', 'now', true);
+            $resp->setReloadCss(true);
         }
 
         if ($this->view->title) {
@@ -515,19 +501,25 @@ class ActionController extends Zend_Controller_Action
             }
             $resp->setHeader(
                 'X-Icinga-Title',
-                rawurlencode($this->view->title . ' :: Icinga Web'),
+                rawurlencode($this->view->title . ' :: ' . $this->view->defaultTitle),
                 true
             );
         } else {
-            $resp->setHeader('X-Icinga-Title', rawurlencode('Icinga Web'), true);
+            $resp->setHeader('X-Icinga-Title', rawurlencode($this->view->defaultTitle), true);
         }
 
+        $layout = $this->_helper->layout();
         if ($this->rerenderLayout) {
-            $this->getResponse()->setHeader('X-Icinga-Container', 'layout', true);
+            $layout->setLayout($this->innerLayout);
+            $resp->setRerenderLayout(true);
+        } else {
+            // The layout may be disabled and there's no indication that the layout is explicitly desired,
+            // that's why we're passing false as second parameter to setLayout
+            $layout->setLayout($this->inlineLayout, false);
         }
 
         if ($this->autorefreshInterval !== null) {
-            $resp->setHeader('X-Icinga-Refresh', $this->autorefreshInterval, true);
+            $resp->setAutoRefreshInterval($this->autorefreshInterval);
         }
     }
 
