@@ -4,6 +4,7 @@
 namespace Icinga\Web;
 
 use Closure;
+use Icinga\Application\Icinga;
 use Zend_View_Abstract;
 use Icinga\Authentication\Auth;
 use Icinga\Exception\ProgrammingError;
@@ -58,13 +59,6 @@ class View extends Zend_View_Abstract
      */
     const CHARSET = 'UTF-8';
 
-    /**
-     * Flag to register stream wrapper
-     *
-     * @var bool
-     */
-    private $useViewStream = false;
-
     /**
      * Registered helper functions
      */
@@ -85,12 +79,7 @@ class View extends Zend_View_Abstract
      */
     public function __construct($config = array())
     {
-        $this->useViewStream = (bool) ini_get('short_open_tag') ? false : true;
-        if ($this->useViewStream) {
-            if (!in_array('zend.view', stream_get_wrappers())) {
-                stream_wrapper_register('zend.view', '\Icinga\Web\ViewStream');
-            }
-        }
+        $config['helperPath']['Icinga\\Web\\View\\Helper\\'] = Icinga::app()->getLibraryDir('Icinga/Web/View/Helper');
 
         parent::__construct($config);
     }
@@ -255,11 +244,8 @@ class View extends Zend_View_Abstract
             // Exporting global variables to view scripts:
             $$k = $v;
         }
-        if ($this->useViewStream) {
-            include 'zend.view://' . func_get_arg(0);
-        } else {
-            include func_get_arg(0);
-        }
+
+        include func_get_arg(0);
     }
 
     /**
