@@ -605,7 +605,7 @@ class Wizard
                 'button',
                 static::BTN_NEXT,
                 array(
-                    'class'         => 'control-button',
+                    'class'         => 'control-button btn-primary',
                     'type'          => 'submit',
                     'value'         => $pages[1]->getName(),
                     'label'         => t('Next'),
@@ -629,7 +629,7 @@ class Wizard
                 'button',
                 static::BTN_NEXT,
                 array(
-                    'class'         => 'control-button',
+                    'class'         => 'control-button btn-primary',
                     'type'          => 'submit',
                     'value'         => $pages[$index + 1]->getName(),
                     'label'         => t('Next'),
@@ -653,7 +653,7 @@ class Wizard
                 'button',
                 static::BTN_NEXT,
                 array(
-                    'class'         => 'control-button',
+                    'class'         => 'control-button btn-primary',
                     'type'          => 'submit',
                     'value'         => $page->getName(),
                     'label'         => t('Finish'),
