@@ -3,8 +3,6 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
-use Zend_Db_Expr;
-
 class HoststatusQuery extends IdoQuery
 {
     /**
@@ -22,6 +20,11 @@ class HoststatusQuery extends IdoQuery
      */
     protected $groupOrigin = array('hostgroups', 'servicegroups', 'services');
 
+    protected $subQueryTargets = array(
+        'hostgroups'    => 'hostgroup',
+        'servicegroups' => 'servicegroup'
+    );
+
     /**
      * {@inheritdoc}
      */
@@ -29,6 +32,12 @@ class HoststatusQuery extends IdoQuery
         'checktimeperiods' => array(
             'host_check_timeperiod' => 'ctp.alias COLLATE latin1_general_ci'
         ),
+        'contacts' => [
+            'host_contact' => 'hco.name1'
+        ],
+        'contactgroups' => [
+            'host_contactgroup' => 'hcgo.name1'
+        ],
         'hostgroups' => array(
             'hostgroup'         => 'hgo.name1 COLLATE latin1_general_ci',
             'hostgroup_alias'   => 'hg.alias COLLATE latin1_general_ci',
@@ -40,6 +49,7 @@ class HoststatusQuery extends IdoQuery
             'host_address'          => 'h.address',
             'host_address6'         => 'h.address6',
             'host_alias'            => 'h.alias',
+            'host_check_interval'   => '(h.check_interval * 60)',
             'host_display_name'     => 'h.display_name COLLATE latin1_general_ci',
             'host_icon_image'       => 'h.icon_image',
             'host_icon_image_alt'   => 'h.icon_image_alt',
@@ -80,6 +90,7 @@ class HoststatusQuery extends IdoQuery
             'host_last_hard_state_change'           => 'UNIX_TIMESTAMP(hs.last_hard_state_change)',
             'host_last_notification'                => 'UNIX_TIMESTAMP(hs.last_notification)',
             'host_last_state_change'                => 'UNIX_TIMESTAMP(hs.last_state_change)',
+            'host_last_state_change_ts'             => 'hs.last_state_change',
             'host_last_time_down'                   => 'UNIX_TIMESTAMP(hs.last_time_down)',
             'host_last_time_unreachable'            => 'UNIX_TIMESTAMP(hs.last_time_unreachable)',
             'host_last_time_up'                     => 'UNIX_TIMESTAMP(hs.last_time_up)',
@@ -90,17 +101,17 @@ class HoststatusQuery extends IdoQuery
             'host_next_notification'                => 'UNIX_TIMESTAMP(hs.next_notification)',
             'host_next_update'                      => 'CASE WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL
             THEN
-                NULL
+                CASE hs.should_be_scheduled WHEN 1 THEN UNIX_TIMESTAMP(hs.next_check) + (hs.normal_check_interval * 60) ELSE NULL END
             ELSE
-                UNIX_TIMESTAMP(hs.last_check)
-                + CASE WHEN
+                UNIX_TIMESTAMP(hs.next_check)
+                + (CASE WHEN
                     COALESCE(hs.current_state, 0) > 0 AND hs.state_type = 0
                 THEN
                     hs.retry_check_interval
                 ELSE
                     hs.normal_check_interval
-                END * 60 * 2
-                + CEIL(hs.execution_time)
+                END * 60)
+                + (CEIL(hs.execution_time + hs.latency) * 2)
             END',
             'host_no_more_notifications'            => 'hs.no_more_notifications',
             'host_normal_check_interval'            => 'hs.normal_check_interval',
@@ -118,41 +129,33 @@ class HoststatusQuery extends IdoQuery
             'host_process_performance_data'         => 'hs.process_performance_data',
             'host_retry_check_interval'             => 'hs.retry_check_interval',
             'host_scheduled_downtime_depth'         => 'hs.scheduled_downtime_depth',
-            'host_severity'                         => 'CASE WHEN hs.current_state = 0
-            THEN
-                CASE WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL
-                     THEN 16
-                     ELSE 0
-                END
-                +
-                CASE WHEN hs.problem_has_been_acknowledged = 1
-                     THEN 2
-                     ELSE
-                        CASE WHEN hs.scheduled_downtime_depth > 0
-                            THEN 1
-                            ELSE 4
+            'host_severity'                         => '
+                CASE
+                    WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL
+                    THEN 16
+                ELSE
+                    CASE 
+                        WHEN hs.current_state = 0
+                        THEN 1
+                    ELSE
+                        CASE
+                            WHEN hs.current_state = 1 THEN 64
+                            WHEN hs.current_state = 2 THEN 32
+                            ELSE 256
                         END
-                END
-            ELSE
-                CASE WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL THEN 16
-                     WHEN hs.current_state = 1 THEN 32
-                     WHEN hs.current_state = 2 THEN 64
-                     ELSE 256
-                END
-                +
-                CASE WHEN hs.problem_has_been_acknowledged = 1
-                     THEN 2
-                     ELSE
-                        CASE WHEN hs.scheduled_downtime_depth > 0
-                            THEN 1
-                            ELSE 4
+                        +
+                        CASE 
+                            WHEN hs.problem_has_been_acknowledged = 1 THEN 2
+                            WHEN hs.scheduled_downtime_depth > 0 THEN 1
+                            ELSE 256
                         END
-                END
-            END',
+                    END
+                END',
             'host_state'                => 'CASE WHEN hs.has_been_checked = 0 OR hs.has_been_checked IS NULL THEN 99 ELSE hs.current_state END',
             'host_state_type'           => 'hs.state_type',
             'host_status_update_time'   => 'hs.status_update_time',
-            'host_unhandled'            => 'CASE WHEN (hs.problem_has_been_acknowledged + hs.scheduled_downtime_depth) = 0 THEN 1 ELSE 0 END'
+            'host_unhandled'            => 'CASE WHEN (hs.problem_has_been_acknowledged + hs.scheduled_downtime_depth) = 0 THEN 1 ELSE 0 END',
+            'problems'                  => 'CASE WHEN COALESCE(hs.current_state, 0) = 0 THEN 0 ELSE 1 END'
         ),
         'instances' => array(
             'instance_name' => 'i.instance_name'
@@ -177,17 +180,16 @@ class HoststatusQuery extends IdoQuery
         if (version_compare($this->getIdoVersion(), '1.10.0', '<')) {
             $this->columnMap['hoststatus']['host_check_source'] = '(NULL)';
         }
-
         if (version_compare($this->getIdoVersion(), '1.13.0', '<')) {
             $this->columnMap['hoststatus']['host_is_reachable'] = '(NULL)';
         }
 
         $this->select->from(
-            array('h' => $this->prefix . 'hosts'),
+            array('ho' => $this->prefix . 'objects'),
             array()
         )->join(
-            array('ho' => $this->prefix . 'objects'),
-            'ho.object_id = h.host_object_id AND ho.is_active = 1 AND ho.objecttype_id = 1',
+            array('h' => $this->prefix . 'hosts'),
+            'h.host_object_id = ho.object_id AND ho.is_active = 1 AND ho.objecttype_id = 1',
             array()
         );
         $this->joinedVirtualTables['hosts'] = true;
@@ -205,6 +207,38 @@ class HoststatusQuery extends IdoQuery
         );
     }
 
+    /**
+     * Join contacts
+     */
+    protected function joinContacts()
+    {
+        $this->select->joinLeft(
+            ['hc' => 'icinga_host_contacts'],
+            'hc.host_id = h.host_id',
+            []
+        )->joinLeft(
+            ['hco' => 'icinga_objects'],
+            'hco.object_id = hc.contact_object_id AND hco.is_active = 1 AND hco.objecttype_id = 10',
+            []
+        );
+    }
+
+    /**
+     * Join contact groups
+     */
+    protected function joinContactgroups()
+    {
+        $this->select->joinLeft(
+            ['hcg' => 'icinga_host_contactgroups'],
+            'hcg.host_id = h.host_id',
+            []
+        )->joinLeft(
+            ['hcgo' => 'icinga_objects'],
+            'hcgo.object_id = hcg.contactgroup_object_id AND hcgo.is_active = 1 AND hcgo.objecttype_id = 11',
+            []
+        );
+    }
+
     /**
      * Join host groups
      */
@@ -299,7 +333,21 @@ class HoststatusQuery extends IdoQuery
             ->columns(array(
                 'host_name',
                 'unhandled_service_count'
-            )
-        );
+            ));
+    }
+
+    protected function joinSubQuery(IdoQuery $query, $name, $filter, $and, $negate, &$additionalFilter)
+    {
+        if ($name === 'hostgroup') {
+            $query->joinVirtualTable('members');
+
+            return ['hgm.host_object_id', 'ho.object_id'];
+        } elseif ($name === 'servicegroup') {
+            $query->joinVirtualTable('services');
+
+            return ['s.host_object_id', 'ho.object_id'];
+        }
+
+        return parent::joinSubQuery($query, $name, $filter, $and, $negate, $additionalFilter);
     }
 }
