@@ -8,6 +8,7 @@ use Icinga\Exception\QueryException;
 use Icinga\Data\Filter\Filter;
 use Icinga\Data\Filterable;
 use Icinga\File\Csv;
+use Icinga\Util\Json;
 use Icinga\Web\Controller as IcingaWebController;
 use Icinga\Web\Url;
 
@@ -31,22 +32,49 @@ class Controller extends IcingaWebController
 
     protected function handleFormatRequest($query)
     {
-        if ($this->_getParam('format') === 'sql') {
-            echo '<pre>'
-                . htmlspecialchars(wordwrap($query->dump()))
-                . '</pre>';
-            exit;
+        $desiredContentType = $this->getRequest()->getHeader('Accept');
+        if ($desiredContentType === 'application/json') {
+            $desiredFormat = 'json';
+        } elseif ($desiredContentType === 'text/csv') {
+            $desiredFormat = 'csv';
+        } else {
+            $desiredFormat = strtolower($this->params->get('format', 'html'));
         }
-        if ($this->_getParam('format') === 'json'
-            || $this->_request->getHeader('Accept') === 'application/json') {
-            header('Content-type: application/json');
-            echo json_encode($query->getQuery()->fetchAll());
-            exit;
+
+        if ($desiredFormat !== 'html' && ! $this->params->has('limit')) {
+            $query->limit();  // Resets any default limit and offset
         }
-        if ($this->_getParam('format') === 'csv'
-            || $this->_request->getHeader('Accept') === 'text/csv') {
-            Csv::fromQuery($query)->dump();
-            exit;
+
+        switch ($desiredFormat) {
+            case 'sql':
+                echo '<pre>'
+                    . htmlspecialchars(wordwrap($query->dump()))
+                    . '</pre>';
+                exit;
+            case 'json':
+                $response = $this->getResponse();
+                $response
+                    ->setHeader('Content-Type', 'application/json')
+                    ->setHeader('Cache-Control', 'no-store')
+                    ->setHeader(
+                        'Content-Disposition',
+                        'inline; filename=' . $this->getRequest()->getActionName() . '.json'
+                    )
+                    ->appendBody(Json::sanitize($query->fetchAll()))
+                    ->sendResponse();
+                exit;
+            case 'csv':
+                $response = $this->getResponse();
+                $response
+                    ->setHeader('Content-Type', 'text/csv')
+                    ->setHeader('Cache-Control', 'no-store')
+                    ->setHeader(
+                        'Content-Disposition',
+                        'attachment; filename=' . $this->getRequest()->getActionName() . '.csv'
+                    )
+                    ->appendBody((string) Csv::fromQuery($query))
+                    ->sendResponse();
+                exit;
         }
     }
 
@@ -69,7 +97,7 @@ class Controller extends IcingaWebController
      *
      * @param   string $name        Name of the restriction
      *
-     * @return  Filter|null         Filter object or null if the authenticated user is not restricted
+     * @return  Filter              Filter object
      * @throws  ConfigurationError  If the restriction contains invalid filter columns
      */
     protected function getRestriction($name)
@@ -87,7 +115,7 @@ class Controller extends IcingaWebController
         ));
         foreach ($this->getRestrictions($name) as $filter) {
             if ($filter === '*') {
-                return Filter::matchAny();
+                return Filter::matchAll();
             }
             try {
                 $restriction->addFilter(Filter::fromQueryString($filter));
@@ -110,7 +138,11 @@ class Controller extends IcingaWebController
                 );
             }
         }
+
+        if ($restriction->isEmpty()) {
+            return Filter::matchAll();
+        }
+
         return $restriction;
     }
 }
-
