@@ -36,6 +36,7 @@ use Icinga\Module\Setup\Requirement\PhpConfigRequirement;
 use Icinga\Module\Setup\Requirement\PhpModuleRequirement;
 use Icinga\Module\Setup\Requirement\PhpVersionRequirement;
 use Icinga\Module\Setup\Requirement\ConfigDirectoryRequirement;
+use Icinga\Module\Monitoring\Forms\Config\Transport\ApiTransportForm;
 
 /**
  * Icinga Web 2 Setup Wizard
@@ -132,17 +133,17 @@ class WebWizard extends Wizard implements SetupWizard
         if ($page->getName() === 'setup_requirements') {
             $page->setWizard($this);
         } elseif ($page->getName() === 'setup_authentication_backend') {
+            /** @var AuthBackendPage $page */
+
             $authData = $this->getPageData('setup_authentication_type');
             if ($authData['type'] === 'db') {
                 $page->setResourceConfig($this->getPageData('setup_auth_db_resource'));
             } elseif ($authData['type'] === 'ldap') {
                 $page->setResourceConfig($this->getPageData('setup_ldap_resource'));
 
-                if (! $this->hasPageData('setup_authentication_backend')) {
-                    $suggestions = $this->getPageData('setup_ldap_discovery');
-                    if (isset($suggestions['backend'])) {
-                        $page->populate($suggestions['backend']);
-                    }
+                $suggestions = $this->getPageData('setup_ldap_discovery');
+                if (isset($suggestions['backend'])) {
+                    $page->setSuggestions($suggestions['backend']);
                 }
 
                 if ($this->getDirection() === static::FORWARD) {
@@ -297,8 +298,7 @@ class WebWizard extends Wizard implements SetupWizard
             $configData = $this->getPageData('setup_general_config');
             $skip = $authData['type'] === 'db' || $configData['global_config_backend'] !== 'db';
         } elseif (in_array($newPage->getName(), array('setup_auth_db_creation', 'setup_config_db_creation'))) {
-            if (
-                ($newPage->getName() === 'setup_auth_db_creation' || $this->hasPageData('setup_config_db_resource'))
+            if (($newPage->getName() === 'setup_auth_db_creation' || $this->hasPageData('setup_config_db_resource'))
                 && (($config = $this->getPageData('setup_auth_db_resource')) !== null
                     || ($config = $this->getPageData('setup_config_db_resource')) !== null)
                     && !$config['skip_validation']
@@ -351,9 +351,13 @@ class WebWizard extends Wizard implements SetupWizard
         $pages = $this->getPages();
         $index = array_search($page, $pages, true);
         if ($index === 0) {
-            $page->getElement(static::BTN_NEXT)->setLabel(mt('setup', 'Start', 'setup.welcome.btn.next'));
+            $page->getElement(static::BTN_NEXT)->setLabel(
+                mt('setup', 'Start', 'setup.welcome.btn.next')
+            );
         } elseif ($index === count($pages) - 1) {
-            $page->getElement(static::BTN_NEXT)->setLabel(mt('setup', 'Setup Icinga Web 2', 'setup.summary.btn.finish'));
+            $page->getElement(static::BTN_NEXT)->setLabel(
+                mt('setup', 'Setup Icinga Web 2', 'setup.summary.btn.finish')
+            );
         }
 
         $authData = $this->getPageData('setup_authentication_type');
@@ -363,7 +367,10 @@ class WebWizard extends Wizard implements SetupWizard
             'setup_auth_db_resource',
             'setup_config_db_resource',
             'setup_ldap_resource',
-            'setup_monitoring_ido'
+            'setup_monitoring_ido',
+            'setup_icingadb_resource',
+            'setup_icingadb_redis',
+            'setup_icingadb_api_transport'
         ))) {
             $page->addElement(
                 'submit',
@@ -377,18 +384,38 @@ class WebWizard extends Wizard implements SetupWizard
             );
             $page->getDisplayGroup('buttons')->addElement($page->getElement('backend_validation'));
         }
+
+        if ($page->getName() === 'setup_command_transport') {
+            if ($page->getSubForm('transport_form')->getSubForm('transport_form') instanceof ApiTransportForm) {
+                $page->addElement(
+                    'submit',
+                    'transport_validation',
+                    array(
+                        'ignore'                => true,
+                        'label'                 => t('Validate Configuration'),
+                        'data-progress-label'   => t('Validation In Progress'),
+                        'decorators'            => array('ViewHelper')
+                    )
+                );
+                $page->getDisplayGroup('buttons')->addElement($page->getElement('transport_validation'));
+            }
+        }
     }
 
     /**
-     * Clear the session being used by this wizard and drop the setup token
+     * Clear the session being used by this wizard
+     *
+     * @param   bool    $removeToken    If true, the setup token will be removed
      */
-    public function clearSession()
+    public function clearSession($removeToken = true)
     {
         parent::clearSession();
 
-        $tokenPath = Config::resolvePath('setup.token');
-        if (file_exists($tokenPath)) {
-            @unlink($tokenPath);
+        if ($removeToken) {
+            $tokenPath = Config::resolvePath('setup.token');
+            if (file_exists($tokenPath)) {
+                @unlink($tokenPath);
+            }
         }
     }
 
@@ -402,8 +429,7 @@ class WebWizard extends Wizard implements SetupWizard
         $pageData = $this->getPageData();
         $setup = new Setup();
 
-        if (
-            isset($pageData['setup_auth_db_resource'])
+        if (isset($pageData['setup_auth_db_resource'])
             && !$pageData['setup_auth_db_resource']['skip_validation']
             && (! isset($pageData['setup_auth_db_creation'])
                 || !$pageData['setup_auth_db_creation']['skip_validation']
@@ -424,8 +450,7 @@ class WebWizard extends Wizard implements SetupWizard
                         ->get('schema', 'path', Icinga::app()->getBaseDir('etc' . DIRECTORY_SEPARATOR . 'schema'))
                 ))
             );
-        } elseif (
-            isset($pageData['setup_config_db_resource'])
+        } elseif (isset($pageData['setup_config_db_resource'])
             && !$pageData['setup_config_db_resource']['skip_validation']
             && (! isset($pageData['setup_config_db_creation'])
                 || !$pageData['setup_config_db_creation']['skip_validation']
@@ -505,8 +530,7 @@ class WebWizard extends Wizard implements SetupWizard
             );
         }
 
-        if (
-            isset($pageData['setup_auth_db_resource'])
+        if (isset($pageData['setup_auth_db_resource'])
             || isset($pageData['setup_config_db_resource'])
             || isset($pageData['setup_ldap_resource'])
         ) {
@@ -546,23 +570,13 @@ class WebWizard extends Wizard implements SetupWizard
         $set = new RequirementSet();
 
         $set->add(new PhpVersionRequirement(array(
-            'condition'     => array('>=', '5.3.2'),
+            'condition'     => array('>=', '5.6'),
             'description'   => mt(
                 'setup',
-                'Running Icinga Web 2 requires PHP version 5.3.2. Advanced features'
-                . ' like the built-in web server require PHP version 5.4.'
+                'Running Icinga Web 2 requires PHP version 5.6.'
             )
         )));
 
-        $set->add(new PhpConfigRequirement(array(
-            'condition'     => array('date.timezone', true),
-            'title'         => mt('setup', 'Default Timezone'),
-            'description'   => sprintf(
-                mt('setup', 'It is required that a default timezone has been set using date.timezone in %s.'),
-                php_ini_loaded_file() ?: 'php.ini'
-            ),
-        )));
-
         $set->add(new OSRequirement(array(
             'optional'      => true,
             'condition'     => 'linux',
