@@ -21,13 +21,6 @@
 
         this.timeCounterTimer = null;
 
-        /**
-         * Whether the mobile menu is shown
-         *
-         * @type {bool}
-         */
-        this.mobileMenu = false;
-
         // detect currentLayout
         var classList = $('#layout').attr('class').split(/\s+/);
         var _this = this;
@@ -51,6 +44,11 @@
             this.enableTimeCounters();
             this.triggerWindowResize();
             this.fadeNotificationsAway();
+
+            $(document).on('click', '#mobile-menu-toggle', this.toggleMobileMenu);
+            $(document).on('keypress', '#search',{ self: this, type: 'key' }, this.closeMobileMenu);
+            $(document).on('mouseleave', '#sidebar', { self: this, type: 'leave' }, this.closeMobileMenu);
+            $(document).on('click', '#sidebar a', { self: this, type: 'navigate' }, this.closeMobileMenu);
         },
 
         fadeNotificationsAway: function() {
@@ -62,10 +60,8 @@
                 .delay(7000)
                 .fadeOut('slow',
             function() {
-                icinga.ui.fixControls();
                 $(this).remove();
             });
-
         },
 
         toggleDebug: function() {
@@ -124,9 +120,9 @@
                         'href',
                         base + '/' + url.replace(/^\//, '')
                     ).on('load', function() {
-                        icinga.ui.fixControls();
                         $oldLink.remove();
                     });
+
                     $newLink.appendTo($('head'));
                 }
             });
@@ -157,7 +153,11 @@
             var $element = element;
 
             if (typeof element === 'string') {
-                $element = $('#' + element);
+                if ($container && $container.length) {
+                    $element = $container.find('#' + element);
+                } else {
+                    $element = $('#' + element);
+                }
 
                 if (! $element.length) {
                     // The name attribute is actually deprecated, on anchor tags,
@@ -179,8 +179,19 @@
                 $element[0].focus();
 
                 if ($container && $container.length) {
-                    $container.scrollTop(0);
-                    $container.scrollTop($element.first().position().top);
+                    if (! $container.is('.container')) {
+                        $container = $container.closest('.container');
+                    }
+
+                    if ($container.css('display') === 'flex' && $container.is('.container')) {
+                        var $controls = $container.find('.controls');
+                        var $content = $container.find('.content');
+                        $content.scrollTop($element.offsetTopRelativeTo($content) - $controls.outerHeight() - (
+                            $element.outerHeight(true) - $element.innerHeight()
+                        ));
+                    } else {
+                        $container.scrollTop($element.first().position().top);
+                    }
                 }
             }
         },
@@ -195,7 +206,6 @@
             var col2 = this.cutContainer($('#col2'));
             var kill = this.cutContainer($('#col1'));
             this.pasteContainer($('#col1'), col2);
-            this.fixControls();
             this.icinga.behaviors.navigation.trySetActiveAndSelectedByUrl($('#col1').data('icingaUrl'));
         },
 
@@ -250,7 +260,7 @@
                     _this.currentLayout
                 );
             }
-            _this.fixControls();
+
             _this.refreshDebug();
         },
 
@@ -321,14 +331,12 @@
             this.icinga.loader.stopPendingRequestsFor($c);
             $c.trigger('close-column');
             $c.html('');
-            this.fixControls();
         },
 
         layout2col: function () {
             if (! this.isOneColLayout()) { return; }
             this.icinga.logger.debug('Switching to double col');
             $('#layout').addClass('twocols');
-            this.fixControls();
             $('#layout').trigger('layout-change');
         },
 
@@ -495,232 +503,37 @@
             return $calc.width() / 1000;
         },
 
-        /**
-         * Initialize all TriStateCheckboxes in the given html
-         */
-        initializeTriStates: function ($html) {
-            $('div.tristate', $html).each(function(index, item) {
-                var $target  = $(item);
-
-                // hide input boxess and remove text nodes
-                $target.find("input").hide();
-                $target.contents().filter(function() { return this.nodeType === 3; }).remove();
-
-                // has three states?
-                var triState = $target.find('input[value="unchanged"]').length > 0 ? 1 : 0;
-
-                // fetch current value from radiobuttons
-                var value  = $target.find('input:checked').first().val();
-
-                $target.append(
-                  '<input class="tristate-dummy" ' +
-                        ' data-icinga-old="' + value + '" data-icinga-tristate="' + triState + '" type="checkbox" ' +
-                        (value === '1' ? 'checked ' : ( value === 'unchanged' ? 'indeterminate="true" ' : ' ' )) +
-                  '/> <b style="visibility: hidden;" class="tristate-changed"> (changed) </b>'
-                );
-                if (triState) {
-                  // TODO: find a better way to activate indeterminate checkboxes after load.
-                  $target.append(
-                    '<script type="text/javascript"> ' +
-                      ' $(\'input.tristate-dummy[indeterminate="true"]\').each(function(i, el){ el.indeterminate = true; }); ' +
-                    '</script>'
-                  );
-                }
-            });
-        },
-
-        /**
-         * Set the value of the given TriStateCheckbox
-         *
-         * @param value     {String}  The value to set, can be '1', '0' and 'unchanged'
-         * @param $checkbox {jQuery}  The checkbox
-         */
-        setTriState: function(value, $checkbox) {
-            switch (value) {
-                case ('1'):
-                    $checkbox.prop('checked', true).prop('indeterminate', false);
-                    break;
-                case ('0'):
-                    $checkbox.prop('checked', false).prop('indeterminate', false);
-                    break;
-                case ('unchanged'):
-                    $checkbox.prop('checked', false).prop('indeterminate', true);
-                    break;
-            }
-        },
-
         /**
          * Toggle mobile menu
          *
          * @param {object} e Event
          */
         toggleMobileMenu: function(e) {
-            var $sidebar = $('#sidebar');
-            var $target = $(e.target);
-            var href = $target.attr('href');
-            if (href) {
-                if (href !== '#') {
-                    $sidebar.removeClass('expanded');
-                }
-            } else if (! $target.is('input')) {
-                $sidebar.toggleClass('expanded');
-            }
+            $('#sidebar').toggleClass('expanded');
         },
 
         /**
-         * Close mobile menu when the enter key was pressed
+         * Close mobile menu when the enter key is pressed during search or the user leaves the sidebar
          *
          * @param {object} e Event
          */
         closeMobileMenu: function(e) {
-            var $search = $('#search');
-            if (e.which === 13 && $search.is(':focus')) {
+            if (e.data.self.currentLayout !== 'minimal') {
+                return;
+            }
+
+            if (e.data.type === 'key') {
+                if (e.which === 13) {
+                    $('#sidebar').removeClass('expanded');
+                    $(e.target)[0].blur();
+                }
+            } else {
                 $('#sidebar').removeClass('expanded');
-                $search[0].blur();
-            }
-        },
-
-        initializeControls: function(container) {
-            var $container = $(container);
-
-            if ($container.parent('.dashboard').length || $('#layout').hasClass('fullscreen-layout')) {
-                return;
-            }
-
-            $container.find('.controls').each(function() {
-                var $controls = $(this);
-                if (! $controls.prev('.fake-controls').length) {
-                    var $tabs = $controls.find('.tabs', $controls);
-                    if ($tabs.length && $controls.children().length > 1 && ! $tabs.next('.tabs-spacer').length) {
-                        $tabs.after($('<div class="tabs-spacer"></div>'));
-                    }
-                    var $fakeControls = $('<div class="fake-controls"></div>');
-                    $fakeControls.height($controls.height()).css({
-                        // That's only temporary. It's reset in fixControls, which is called at the end of this
-                        // function. Its purpose is to prevent the content from jumping up upon auto-refreshes.
-                        // It works by making the fake-controls appear at the same vertical level as the controls
-                        // and the height of the content then doesn't change when taking the controls out of the flow.
-                        float: 'right'
-                    });
-                    $controls.before($fakeControls).css({
-                        position: 'fixed'
-                    });
-                }
-            });
-
-            this.fixControls($container);
-        },
-
-        fixControls: function($container) {
-            var $layout = $('#layout');
-
-            if ($layout.hasClass('fullscreen-layout')) {
-                return;
-            }
-
-            if (typeof $container === 'undefined') {
-                var $header = $('#header');
-                var $headerLogo = $('#header-logo-container');
-                var $main = $('#main');
-                var $search = $('#search');
-                var $sidebar = $('#sidebar');
-
-                $header.css({ height: 'auto'});
-
-                if ($layout.hasClass('minimal-layout')) {
-                    if (! this.mobileMenu && $sidebar.length) {
-                        $header.css({
-                            top: $sidebar.outerHeight() + 'px'
-                        });
-                        $headerLogo.css({
-                            display: 'none'
-                        });
-                        $main.css({
-                            top: $header.outerHeight() + $sidebar.outerHeight()
-                        });
-                        $sidebar
-                            .on(
-                                'click',
-                                this.toggleMobileMenu
-                            )
-                            .prepend(
-                                $('<div id="mobile-menu-toggle"><button><i class="icon-menu"></i><i class="icon-cancel"></i></button></div>')
-                            );
-                            $('#header-logo').clone().attr('id', 'mobile-menu-logo')
-                                .appendTo('#mobile-menu-toggle');
-                        $(window).on('keypress', this.closeMobileMenu);
-
-                        this.mobileMenu = true;
-                    }
-                } else {
-                    $headerLogo.css({
-                        top: $header.css('height')
-                    });
-                    $main.css({
-                        top: $header.css('height')
-                    });
-                    if (!! $headerLogo.length) {
-                        $sidebar.css({
-                            top: $headerLogo.offset().top + $headerLogo.outerHeight()
-                        });
-                    }
-
-                    if (this.mobileMenu) {
-                        $header.css({
-                            top: 0
-                        });
-                        $headerLogo.css({
-                            display: 'block'
-                        });
-                        $sidebar.removeClass('expanded').off('click', this.toggleMobileMenu);
-                        $search.off('keypress', this.closeMobileMenu);
-                        $('#mobile-menu-toggle').remove();
-
-                        this.mobileMenu = false;
-                    }
-                }
-
-                var _this = this;
-                $('.container').each(function () {
-                    _this.fixControls($(this));
-                });
-
-                return;
-            }
-
-            if ($container.parent('.dashboard').length) {
-                return;
-            }
-
-            // Enable this only in case you want to track down UI problems
-            //this.icinga.logger.debug('Fixing controls for ', $container);
-
-            $container.find('.controls').each(function() {
-                var $controls = $(this);
-                var $fakeControls = $controls.prev('.fake-controls');
-                $fakeControls.css({
-                    float: '', // Set by initializeControls
-                    height: $controls.height()
-                });
-                $controls.css({
-                    top: $container.offsetParent().position().top,
-                    width: $fakeControls.outerWidth()
-                });
-            });
-
-            var $statusBar = $container.children('.monitoring-statusbar');
-            if ($statusBar.length) {
-                $statusBar.css({
-                    left: $container.offset().left,
-                    width: $container.width()
-                });
-                $statusBar.prev('.monitoring-statusbar-ghost').height($statusBar.outerHeight(true));
             }
         },
 
         toggleFullscreen: function () {
             $('#layout').toggleClass('fullscreen-layout');
-            this.fixControls();
         },
 
         getUniqueContainerId: function ($cont) {
@@ -735,7 +548,7 @@
                  * This is based on the assumption that the server only knows about the menu and first column
                  * and therefore does not need to protect its ids. (As the menu is most likely part of the sidebar)
                  */
-                if ($cont.attr('id') === 'menu' || $cont.attr('id') === 'col1') {
+                if ($cont.attr('id') === 'menu' || $cont.attr('id') === 'col1' || $cont.closest('#col1').length) {
                     return null;
                 }
 
